Read-only mirrors. Development, issues and pull requests are on GitHub.

summaryrefslogtreecommitdiffhomepage
path: root/tests/TestScripts/testConfigureDisableStringification.py
diff options
context:
space:
mode:
authorMartin Hořeňovský2025-08-22 17:03:31 +0200
committerMartin Hořeňovský2025-08-22 17:03:35 +0200
commitf4e05a67bb5a57ee6e051fc8c391b32cbf927f7d (patch)
tree1231b6f4733bb718eddb8435260dd001dca7179c /tests/TestScripts/testConfigureDisableStringification.py
parentfb2e4fbe413824a5cad4101c0e94cb10b7828f0d (diff)
downloadcatch3-f4e05a67bb5a57ee6e051fc8c391b32cbf927f7d.tar.gz
Improve performance of writing XML
As with the JSON writer, the old code was made to be simple and for each char just decided whether it needs escaping, or should be written as-is. The new code instead looks for characters that need escaping and batches writes of characters that do not. This provides 4-8x speedup (length dependent) for writing strings that do not need escaping, and keeps roughly the same performance for those that do need escaping.
Diffstat (limited to 'tests/TestScripts/testConfigureDisableStringification.py')
0 files changed, 0 insertions, 0 deletions